==> 1.0.0-dev.2.tar.gz: test/agent/http/dns_info_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:tingyun_flutter_plugin/src/agent/http/dns_info.dart';

void main(){
  test('addDnsInfoToMap', (){
    DnsInfo.addDnsInfoToMap("123", DnsInfo('123', '1.1.1.1', 10));

    expect(DnsInfo.isKeyExist(null), false);
    expect(DnsInfo.isKeyExist(""), false);
    expect(DnsInfo.isKeyExist("123"), true);
    expect(DnsInfo.getIpAddress("123"), '1.1.1.1');
    expect(DnsInfo.getDnsDuration("123"), 10);

    expect(DnsInfo.getIpAddress("123"), '1.1.1.1');
    expect(DnsInfo.getDnsDuration("123"), 0);

    DnsInfo.addDnsInfoToMap("123", DnsInfo('123', '2.2.2.2', 2));
    expect(DnsInfo.getIpAddress("123"), '1.1.1.1');
    expect(DnsInfo.getDnsDuration("123"), 0);

    expect(DnsInfo.getMaplength(), 1);


    DnsInfo.addDnsInfoToMap("456", DnsInfo('456', '2.2.2.2', 6));
    expect(DnsInfo.getIpAddress("456"), '');
    expect(DnsInfo.getDnsDuration("456"), 0);
    expect(DnsInfo.getMaplength(), 1);


    DnsInfo.addDnsInfoToMap("456", DnsInfo('456', '2.2.2.2', 20));
    expect(DnsInfo.getIpAddress("456"), '2.2.2.2');
    expect(DnsInfo.getDnsDuration("456"), 20);
    expect(DnsInfo.getMaplength(), 2);

    print('test addDnsInfoToMap ');

  });

  test('dns setDnsInfo', () async{
    print('111111');
    String url = "sdkjfansdfllwww.qq.com";
    try {
      await DnsInfo.setDnsInfo(Uri
          .parse(url)
          .host);
      print('3333');
    }catch (e) {
      print("error111 setDnsInfo :${e.toString()}");
    }
    print('22222');


    // try {
    //   DnsInfo.setDnsInfo(Uri.parse(url).host);
    // } catch (e) {
    //   Logger().d("error setDnsInfo :${e.toString()}");
    // }
  });
}

==> 2.1.0.tar.gz: test/agent/http/dns_info_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'package:tingyun_flutter_plugin/src/agent/http/dns_info.dart';

void main(){
  test('addDnsInfoToMap', (){
    DnsInfo.addDnsInfoToMap("123", DnsInfo('123', '1.1.1.1', 10));

    expect(DnsInfo.isKeyExist(""), false);
    expect(DnsInfo.isKeyExist("123"), true);
    expect(DnsInfo.getIpAddress("123"), '1.1.1.1');
    expect(DnsInfo.getDnsDuration("123"), 10);

    expect(DnsInfo.getIpAddress("123"), '1.1.1.1');
    expect(DnsInfo.getDnsDuration("123"), 0);

    DnsInfo.addDnsInfoToMap("123", DnsInfo('123', '2.2.2.2', 2));
    expect(DnsInfo.getIpAddress("123"), '1.1.1.1');
    expect(DnsInfo.getDnsDuration("123"), 0);

    expect(DnsInfo.getMaplength(), 1);


    DnsInfo.addDnsInfoToMap("456", DnsInfo('456', '2.2.2.2', 6));
    expect(DnsInfo.getIpAddress("456"), '');
    expect(DnsInfo.getDnsDuration("456"), 0);
    expect(DnsInfo.getMaplength(), 1);


    DnsInfo.addDnsInfoToMap("456", DnsInfo('456', '2.2.2.2', 20));
    expect(DnsInfo.getIpAddress("456"), '2.2.2.2');
    expect(DnsInfo.getDnsDuration("456"), 20);
    expect(DnsInfo.getMaplength(), 2);

    print('test addDnsInfoToMap ');

  });

  test('dns setDnsInfo', () async{
    print('111111');
    String url = "sdkjfansdfllwww.qq.com";
    try {
      DnsInfo.setDnsInfo(Uri
          .parse(url)
          .host);
      print('3333');
    }catch (e) {
      print("error111 setDnsInfo :${e.toString()}");
    }
    print('22222');


    // try {
    //   DnsInfo.setDnsInfo(Uri.parse(url).host);
    // } catch (e) {
    //   Logger().d("error setDnsInfo :${e.toString()}");
    // }
  });
}
